Index: trunk/MagicSoft/Mars/mhbase/MH3.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MH3.cc	(revision 6915)
+++ trunk/MagicSoft/Mars/mhbase/MH3.cc	(revision 6917)
@@ -32,5 +32,5 @@
 // In the constructor you can give up to three variables which should be
 // filled in the histogram. Dependend on the number of given variables
 // (data members) a TH1F, TH2F or TH3F is created.
 // Specify the data mamber like the following:
 //   "MHillas.fLength"
@@ -108,13 +108,13 @@
     {
     case 1:
-        fHist = new TH1F;
+        fHist = new TH1D;
         fHist->SetYTitle("Counts");
         break;
     case 2:
-        fHist = new TH2F;
+        fHist = new TH2D;
         fHist->SetZTitle("Counts");
         break;
     case 3:
-        fHist = new TH3F;
+        fHist = new TH3D;
         break;
     }
@@ -140,5 +140,5 @@
 // --------------------------------------------------------------------------
 //
 // Creates an TH1F. memberx is filled into the X-bins. For a more detailed
 // description see the class description above.
 //
@@ -146,5 +146,5 @@
     : fDimension(1)
 {
-    fHist = new TH1F;
+    fHist = new TH1D;
 
     fData[0] = new MDataChain(memberx);
@@ -198,5 +198,5 @@
 // --------------------------------------------------------------------------
 //
 // Creates an TH2F. memberx is filled into the X-bins. membery is filled
 // into the Y-bins. For a more detailed description see the class
 // description above.
@@ -205,5 +205,5 @@
     : fDimension(2)
 {
-    fHist = new TH2F;
+    fHist = new TH2D;
 
     fData[0] = new MDataChain(memberx);
@@ -225,5 +225,5 @@
 // --------------------------------------------------------------------------
 //
 // Creates an TH3F. memberx is filled into the X-bins. membery is filled
 // into the Y-bins. membery is filled into the Z-bins. For a more detailed
 // description see the class description above.
@@ -232,5 +232,5 @@
     : fDimension(3)
 {
-    fHist = new TH3F;
+    fHist = new TH3D;
 
     fData[0] = new MDataChain(memberx);
@@ -32,5 +32,5 @@
 // In the constructor you can give up to three variables which should be
 // filled in the histogram. Dependend on the number of given variables
-// (data members) a TH1F, TH2F or TH3F is created.
+// (data members) a TH1D, TH2D or TH3D is created.
 // Specify the data mamber like the following:
 //   "MHillas.fLength"
@@ -140,5 +140,5 @@
 // --------------------------------------------------------------------------
 //
-// Creates an TH1F. memberx is filled into the X-bins. For a more detailed
+// Creates an TH1D. memberx is filled into the X-bins. For a more detailed
 // description see the class description above.
 //
@@ -198,5 +198,5 @@
 // --------------------------------------------------------------------------
 //
-// Creates an TH2F. memberx is filled into the X-bins. membery is filled
+// Creates an TH2D. memberx is filled into the X-bins. membery is filled
 // into the Y-bins. For a more detailed description see the class
 // description above.
@@ -225,5 +225,5 @@
 // --------------------------------------------------------------------------
 //
-// Creates an TH3F. memberx is filled into the X-bins. membery is filled
+// Creates an TH3D. memberx is filled into the X-bins. membery is filled
 // into the Y-bins. membery is filled into the Z-bins. For a more detailed
 // description see the class description above.
